Module shader

Module shader 

Shader trait definitions and argument binding.

Structs

BindGroupLayoutInfo
Information about bind group layouts derived from ShaderArgs. Maps descriptor set index to binding entries.

Enums

ShaderArgsError
Errors that can occur when writing shader arguments to a dispatch.

Traits

Shader
A collection of GPU compute functions that can be instantiated from a backend.
ShaderArgs
Trait for types that can write shader arguments to a dispatch.
ShaderArgsType
Trait for types that represent a “family” of ShaderArgs with different lifetimes.