Shader trait definitions and argument binding.
Structs
- Bind
Group Layout Info - Information about bind group layouts derived from ShaderArgs. Maps descriptor set index to binding entries.
Enums
- Shader
Args Error - Errors that can occur when writing shader arguments to a dispatch.
Traits
- Shader
- A collection of GPU compute functions that can be instantiated from a backend.
- Shader
Args - Trait for types that can write shader arguments to a dispatch.
- Shader
Args Type - Trait for types that represent a “family” of ShaderArgs with different lifetimes.